@@ -485,12 +485,13 @@ class CSVEncoder(TimeSeriesEncoder):
            return
         
         if vals.dtype != object:
-            # Check functional column
-            x_ = PolynomialFeatures(degree=1, include_bias=True).fit_transform(np.asarray(self.times).reshape(-1, 1))
-            model = LinearRegression(fit_intercept=False).fit(x_, vals)
-            if model.score(x_, vals) == 1.0:
-                self._set_functional_column(column_name=value_column, model=model)
-                return
+            if self.functional_compression == True:
+                # Check functional column
+                x_ = PolynomialFeatures(degree=1, include_bias=True).fit_transform(np.asarray(self.times).reshape(-1, 1))
+                model = LinearRegression(fit_intercept=False).fit(x_, vals)
+                if model.score(x_, vals) == 1.0:
+                    self._set_functional_column(column_name=value_column, model=model)
+                    return
         
             # Calculate encoder params
             encoding_depth, max_prec, num_type, signed = EncoderHelpers.calculate_bit_depth(vals, encoding_size=self.encoding_size)
@@ -520,12 +521,12 @@ class CSVEncoder(TimeSeriesEncoder):
         return np.asarray(words).reshape(-1, 1)
 
     @staticmethod
-    def encode_csv(csv, time_column, key_columns, sort_values = True, encoding_size = 64, gzip=False):
+    def encode_csv(csv, time_column, key_columns, sort_values = True, encoding_size = 64, gzip=False, functional_compression=False):
         df = pd.read_csv(StringIO(csv))
         if sort_values:
             df = df.sort_values(time_column, ascending=True)
 
-        encoder = CSVEncoder(encoding_size=encoding_size)
+        encoder = CSVEncoder(encoding_size=encoding_size, functional_compression=functional_compression)
         encoder.columns = list(df.columns)
 
         ndf = pd.DataFrame(encoder.encode_time(df, time_column), columns=[time_column])
@@ -678,11 +679,12 @@ class CSVEncoder(TimeSeriesEncoder):
         ndf = ndf[json_data["columns"]]
         return ndf.to_csv(index=False)
 
-    def __init__(self, encoding_size=64):
+    def __init__(self, encoding_size=64, functional_compression=False):
         self.encoding_size = encoding_size
         self.value_columns = {}
         self.time = {}
         self.keys = {}
+        self.functional_compression = functional_compression
 
 
 
